@@ -31,7 +31,7 @@ def ebay_timestamp_string(datetime_obj):
     # convert python datetime obj to string representation used by eBay
     # appears to be a bug in suds - eBay's milliseconds are loaded into python datetime
     # as microseconds so the datetime_obj we get from suds is not accurate to the data
-    return '%(year)d-%(month)d-%(day)dT%(hour)d:%(minute)d:%(second)d.%(millisecond)dZ' % {
+    return '%(year)s-%(month)s-%(day)sT%(hour)s:%(minute)s:%(second)s.%(millisecond)sZ' % {
         'year': '%04d' % datetime_obj.year,
         'month': '%02d' % datetime_obj.month,
         'day': '%02d' % datetime_obj.day,
